==> aliyun-python-sdk-devops-rdc-1.9.0.tar.gz: aliyun-python-sdk-devops-rdc-1.9.0/aliyunsdkdevops_rdc/request/v20200303/UpdatePipelineMemberRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class UpdatePipelineMemberRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'UpdatePipelineMember')
		self.set_method('POST')

	def get_RoleName(self):
		return self.get_body_params().get('RoleName')

	def set_RoleName(self,RoleName):
		self.add_body_params('RoleName', RoleName)

	def get_UserPk(self):
		return self.get_body_params().get('UserPk')

	def set_UserPk(self,UserPk):
		self.add_body_params('UserPk', UserPk)

	def get_UserId(self):
		return self.get_body_params().get('UserId')

	def set_UserId(self,UserId):
		self.add_body_params('UserId', UserId)

	def get_OrgId(self):
		return self.get_query_params().get('OrgId')

	def set_OrgId(self,OrgId):
		self.add_query_param('OrgId',OrgId)

	def get_PipelineId(self):
		return self.get_query_params().get('PipelineId')

	def set_PipelineId(self,PipelineId):
		self.add_query_param('PipelineId',PipelineId)

==> aliyun-python-sdk-devops-rdc-2.0.2.tar.gz: aliyun-python-sdk-devops-rdc-2.0.2/aliyunsdkdevops_rdc/request/v20200303/UpdatePipelineMemberRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class UpdatePipelineMemberRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'UpdatePipelineMember')
		self.set_method('POST')

	def get_RoleName(self): # String
		return self.get_body_params().get('RoleName')

	def set_RoleName(self, RoleName):  # String
		self.add_body_params('RoleName', RoleName)
	def get_UserPk(self): # String
		return self.get_body_params().get('UserPk')

	def set_UserPk(self, UserPk):  # String
		self.add_body_params('UserPk', UserPk)
	def get_UserId(self): # String
		return self.get_body_params().get('UserId')

	def set_UserId(self, UserId):  # String
		self.add_body_params('UserId', UserId)
	def get_OrgId(self): # String
		return self.get_query_params().get('OrgId')

	def set_OrgId(self, OrgId):  # String
		self.add_query_param('OrgId', OrgId)
	def get_PipelineId(self): # Long
		return self.get_query_params().get('PipelineId')

	def set_PipelineId(self, PipelineId):  # Long
		self.add_query_param('PipelineId', PipelineId)
